# Code Description: 
# - The lambda function code below is triggered when there is a configuration change to an EC2 resource. 
# - When triggered, the code will evaluate whether the EC2 instance (in the event object) has a keypair attached to it. 
# - The lambda will return the result of the evaluation to the target rule in AWS Config. 


import json
import boto3
import logging

# Create logger
logger = logging.getLogger()
logger.setLevel(logging.INFO)

# Handler function
def lambda_handler(event, context):
    
    # log event and contect
    logger.debug(event)

    # Get the invoking event
    invokingEvent = json.loads(event.get('invokingEvent'))
    configurationItem = invokingEvent.get('configurationItem')
    ruleParams = json.loads(event.get('ruleParameters'))
    
    # Log variables
    logger.debug(invokingEvent)
    logger.debug(configurationItem)
    logger.debug(ruleParams)
    
    
    # Evaluate compliance
    evaluation = evaluateCompliance(configurationItem)
    logger.info(evaluation)
    
    # Put evaluation in AWS Config (and associate with custom rule)
    config = boto3.client('config')
    response = config.put_evaluations(
        Evaluations = [{
            'ComplianceResourceType': configurationItem['resourceType'],
            'ComplianceResourceId': configurationItem['resourceId'],
            'ComplianceType': evaluation["compliance_type"],
            'Annotation': evaluation["annotation"],
            'OrderingTimestamp': configurationItem['configurationItemCaptureTime'] 
        }], ResultToken=event['resultToken'])
    logger.info(response)
    
    
    
def evaluateCompliance(configurationItem): 
    
    # Get configuration object
    configuration = configurationItem.get('configuration')
    keyName = configuration.get('keyName')
    logger.debug(configuration)
    logger.debug(keyName)

    if keyName: 
        result = {
            "compliance_type": "COMPLIANT", 
            "annotation": "Instance has been assigned a keypair."
        }
    else: 
        result = {
            "compliance_type": "NON_COMPLIANT", 
            "annotation": "Instance has not been assigned a keypair. "
        }        
        
    # Return result
    return result
        
    
    
    



